@@ -1,8 +1,6 @@
 //! This module contains all the traits and types for creating a cross-platform API to query
 //! different readouts from various operating systems. For each operating system, there must be an implementation of these traits.
 #![allow(unused_variables)]
-use serde::{Serialize, Deserialize};
-
 
 /// This enum contains possible error types when doing sensor & variable readouts.
 #[derive(Debug, Clone)]
@@ -515,6 +513,15 @@ pub enum ShellFormat {
     Absolute,
 }
 
+#[derive(Debug)]
+/// There are two distinct kinds of shells, a so called *"current"* shell, i.e. the shell the user is currently using.
+/// And a default shell, i.e. that the user sets for themselves using the `chsh` tool.
+pub enum ShellKind {
+    Current,
+    Default,
+}
+
+
 /// The supported package managers whose packages can be extracted.
 pub enum PackageManager {
     Homebrew,
@@ -554,24 +561,4 @@ impl ToString for PackageManager {
             PackageManager::Android => "Android",
         })
     }
-}
-
-#[derive(PartialEq, Debug, Serialize, Deserialize)]
-/// There are two distinct kinds of shells, a so called *"current"* shell, i.e. the shell the user is currently using.
-/// And a default shell, i.e. that the user sets for themselves using the `chsh` tool.
-pub enum ShellKind {
-    Current,
-    Default,
-}
-
-impl std::str::FromStr for ShellKind {
-    type Err = ();
-
-    fn from_str(input: &str) -> Result<ShellKind, Self::Err> {
-        match input {
-            "Default" => Ok(ShellKind::Default),
-            "Current" => Ok(ShellKind::Current),
-            _ => Err(()),
-        }
-    }
-}
+}
\ No newline at end of file
